unit uMsgBoxImpl;

interface

uses
  SysUtils, Classes, Dialogs, Graphics,
  uMsgBoxIntf;

type
  TCustomMessageBox = class(TInterfacedObject, IMessageBox)
  private
    FMsg: string;
    FDlgType: TMsgDlgType;
    FButtons: TMsgDlgButtons;
    FX, FY: Integer;
    FTitle: string;
    FColor, FFontColor: TColor;
  public
    constructor Create;
    { IMessageBox }
    procedure SetMsg(AMsg: PChar);
    procedure SetDlgType(ADlgType: TMsgDlgType);
    procedure SetButtons(AButtons: TMsgDlgButtons);
    procedure SetXY(X, Y: Integer);
    procedure SetTitle(ATitle: PChar);
    procedure SetColor(AColor: TColor);
    procedure SetFontColor(AFontColor: TColor);
    function Show: Integer;
  end;

implementation

uses
  Forms, StdCtrls;

{ TCustomMessageBox }

constructor TCustomMessageBox.Create;
begin
  FX := -1;
  FY := -1;
  SetButtons([mbOK]);
  SetColor(clBtnFace);
  SetFontColor(clWindowText);
end;

procedure TCustomMessageBox.SetMsg(AMsg: PChar);
begin
  FMsg := AMsg;
end;

procedure TCustomMessageBox.SetDlgType(ADlgType: TMsgDlgType);
begin
  FDlgType := ADlgType;
end;

procedure TCustomMessageBox.SetButtons(AButtons: TMsgDlgButtons);
begin
  FButtons := AButtons;
end;

procedure TCustomMessageBox.SetXY(X, Y: Integer);
begin
  FX := X;
  FY := Y;
end;

procedure TCustomMessageBox.SetTitle(ATitle: PChar);
begin
  FTitle := ATitle;
end;

procedure TCustomMessageBox.SetColor(AColor: TColor);
begin
  FColor := AColor;
end;

procedure TCustomMessageBox.SetFontColor(AFontColor: TColor);
begin
  FFontColor := AFontColor;
end;

function TCustomMessageBox.Show: Integer;
var
  I: Integer;
begin
  with CreateMessageDialog(FMsg, FDlgType, FButtons) do
    try
      HelpContext := -1;
      HelpFile := '';
      if FX >= 0 then Left := FX;
      if FY >= 0 then Top := FY;
      if (FY < 0) and (FX < 0) then Position := poScreenCenter;

      Caption := FTitle;
      Color := FColor;

      for I := 0 to ComponentCount -1 do
      begin
        if Components[I] is TLabel then
          TLabel(Components[I]).Font.Color := FFontColor;
      end;

      Result := ShowModal;
    finally
      Free;
    end;
end;

end.
